searchNodes=[{"type":"module","title":"FastThumbnail","doc":"FastThumbnail FastThumbnail is an Elixir library that uses a Rust NIF under the hood to perform fast, SIMD-optimized image resizing. It leverages the excellent fast_image_resize crate to crop and resize images efficiently. Why? Fast : SIMD-accelerated resizing is blazingly fast. I just wanted stupidly simple image resizing that do just one thing: crop and resize an image to a given width. There is already good libraries for this image , but they all seem to be too complex for my needs. Also I like small dependencies. Features Center-crop images to a square, then resize (all in a single pass). Multiple output modes : Overwrite the original file with the same format (JPEG stays JPEG, PNG stays PNG, etc.). Save a new file in WebP format ( &quot;path.webp&quot; ). Return the resized image as a base64-encoded WebP string (no file writing). Backed by SIMD operations for maximum performance, thanks to the fast_image_resize library. Installation Add fast_thumbnail to your dependencies in mix.exs : def deps do [ { :fast_thumbnail , &quot;~&gt; 0.1.4&quot; } ] end Then run: mix deps.get mix compile Usage # 1) Overwrite file in its original format (JPEG→JPEG, PNG→PNG, etc.) iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :overwrite ) { :ok , &quot;images/photo.jpg&quot; } # 2) Create a new file in WebP format: iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :webp ) { :ok , &quot;images/photo.jpg.webp&quot; } # 3) Return a base64-encoded WebP (no file writing): iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :base64 ) { :ok , &quot;data:image/webp;base64,UklGRrwAAABXRUJQVlA4T...&quot; } Example Liveview Below is a LiveView : defmodule MyAppWeb.UploadLive do use MyAppWeb , :live_view @impl Phoenix.LiveView def mount ( _params , _session , socket ) do socket = socket # Limit to .jpg, .jpeg for this example |&gt; allow_upload ( :avatar , accept : ~w(.jpg .jpeg) , max_entries : 2 ) { :ok , socket } end @impl Phoenix.LiveView def handle_event ( &quot;validate&quot; , _params , socket ) do { :noreply , socket } end @impl Phoenix.LiveView def handle_event ( &quot;cancel-upload&quot; , %{ &quot;ref&quot; =&gt; ref } , socket ) do { :noreply , cancel_upload ( socket , :avatar , ref ) } end @impl Phoenix.LiveView def handle_event ( &quot;save&quot; , _params , socket ) do uploaded_files = consume_uploaded_entries ( socket , entry , fn %{ path : tmp_path } -&gt; save_result = save_and_process_upload ( entry . client_name , tmp_path ) end ) # Make all check on uploaded_files {:ok, file} or {:ok, {:error, reason}} { :noreply , update ( socket , :uploaded_files , &amp; ( &amp;1 ++ uploaded_files ) ) } end defp save_and_process_upload ( name , tmp_path ) do thumb_result = FastThumbnail . create ( tmp_path , 200 , :webp ) case thumb_result do { :ok , thumb_path } -&gt; s3_result = upload_to_s3 ( thumb_path , name &lt;&gt; &quot;.webp&quot; ) case s3_result do { :ok , s3_url } -&gt; { :ok , s3_url } { :error , reason } -&gt; { :ok , { :error , reason } } # otherwise you can postone end { :error , reason } -&gt; { :error , reason } end end defp upload_to_s3 ( file_path , name_for_s3 ) do # Build your AWS client access_key = System . get_env ( &quot;AWS_ACCESS_KEY&quot; ) secret_key = System . get_env ( &quot;AWS_SECRET_KEY&quot; ) region = System . get_env ( &quot;AWS_REGION&quot; ) bucket = System . get_env ( &quot;AWS_BUCKET_NAME&quot; ) || &quot;my-bucket&quot; client = AWS.Client . create ( access_key , secret_key , region ) # Read the local WebP thumbnail bytes file_body = File . read! ( file_path ) # We&#39;ll store it in S3 at some key (like &quot;thumbnails/&lt;filename&gt;.webp&quot;) # This is just an example – adjust folder/paths as needed folder = &quot;thumbnails&quot; key = &quot; \#{ folder } / \#{ name_for_s3 } &quot; s3_url = &quot;https://s3. \#{ region } .amazonaws.com/ \#{ bucket } / \#{ key } &quot; # S3 `put_object` params put_params = %{ &quot;Body&quot; =&gt; file_body , &quot;ContentType&quot; =&gt; &quot;image/webp&quot; , &quot;Metadata&quot; =&gt; %{ &quot;OriginalName&quot; =&gt; name_for_s3 } } case AWS.S3 . put_object ( client , bucket , key , put_params ) do { :ok , _ , _ } -&gt; { :ok , s3_url } { :error , reason } -&gt; { :error , reason } end end end With this, you have a LiveView flow that: Accepts user uploads, Creates a resized webp thumbnail, Uploads it to S3, Returns the final S3 URL or a local URL. Under the hood, the Elixir function calls a Rust NIF which performs a single-pass crop+resize operation using fast_image_resize . The resized bytes are either: Written back to disk in the same or different format, or Returned to Elixir as a base64 string. Credits fast_image_resize – the Rust crate that powers the SIMD-accelerated resizing. See also: Crates.io Docs.rs rustler – used for building the native Rust code as an Elixir NIF. License FastThumbnail is licensed under the Apache License, Version 2.0 . fast_image_resize is distributed under its own license. Please refer to its repository for details.","ref":"FastThumbnail.html"},{"type":"function","title":"FastThumbnail.create/3","doc":"Creates a thumbnail (width x width), cropping to center, and returning {:ok, path} or {:error, reason}. Modes: :base64 : return a base64-encoded WebP (no file I/O) :webp : write a new &quot;{path}.webp&quot; file :overwrite : overwrite in the original format (JPEG→JPEG, PNG→PNG, etc.) Example: FastThumbnail . create ( &quot;path/to/image.jpg&quot; , 200 , :webp ) # =&gt; {:ok, &quot;path/to/image.webp&quot;} FastThumbnail . create ( &quot;path/to/image.jpg&quot; , 200 , :overwrite ) # =&gt; {:ok, &quot;path/to/image.jpg&quot;} FastThumbnail . create ( &quot;path/to/image.jpg&quot; , 200 , :base64 ) # =&gt; {:ok, &quot;data:image/webp;base64,iVBORw0KGgoAAAANSUhEUgAAA...&quot;}","ref":"FastThumbnail.html#create/3"},{"type":"extras","title":"FastThumbnail","doc":"FastThumbnail is an Elixir library that uses a Rust NIF under the hood to perform fast, SIMD-optimized image resizing. It leverages the excellent fast_image_resize crate to crop and resize images efficiently. Why? Fast : SIMD-accelerated resizing is blazingly fast. I just wanted stupidly simple image resizing that do just one thing: crop and resize an image to a given width. There is already good libraries for this image , but they all seem to be too complex for my needs. Also I like small dependencies.","ref":"readme.html"},{"type":"extras","title":"FastThumbnail - Features","doc":"Center-crop images to a square, then resize (all in a single pass). Multiple output modes : Overwrite the original file with the same format (JPEG stays JPEG, PNG stays PNG, etc.). Save a new file in WebP format ( &quot;path.webp&quot; ). Return the resized image as a base64-encoded WebP string (no file writing). Backed by SIMD operations for maximum performance, thanks to the fast_image_resize library.","ref":"readme.html#features"},{"type":"extras","title":"FastThumbnail - Installation","doc":"Add fast_thumbnail to your dependencies in mix.exs : def deps do [ { :fast_thumbnail , &quot;~&gt; 0.1.4&quot; } ] end Then run: mix deps.get mix compile","ref":"readme.html#installation"},{"type":"extras","title":"FastThumbnail - Usage","doc":"# 1) Overwrite file in its original format (JPEG→JPEG, PNG→PNG, etc.) iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :overwrite ) { :ok , &quot;images/photo.jpg&quot; } # 2) Create a new file in WebP format: iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :webp ) { :ok , &quot;images/photo.jpg.webp&quot; } # 3) Return a base64-encoded WebP (no file writing): iex&gt; FastThumbnail . create ( &quot;images/photo.jpg&quot; , 300 , :base64 ) { :ok , &quot;data:image/webp;base64,UklGRrwAAABXRUJQVlA4T...&quot; }","ref":"readme.html#usage"},{"type":"extras","title":"FastThumbnail - Example Liveview","doc":"Below is a LiveView : defmodule MyAppWeb.UploadLive do use MyAppWeb , :live_view @impl Phoenix.LiveView def mount ( _params , _session , socket ) do socket = socket # Limit to .jpg, .jpeg for this example |&gt; allow_upload ( :avatar , accept : ~w(.jpg .jpeg) , max_entries : 2 ) { :ok , socket } end @impl Phoenix.LiveView def handle_event ( &quot;validate&quot; , _params , socket ) do { :noreply , socket } end @impl Phoenix.LiveView def handle_event ( &quot;cancel-upload&quot; , %{ &quot;ref&quot; =&gt; ref } , socket ) do { :noreply , cancel_upload ( socket , :avatar , ref ) } end @impl Phoenix.LiveView def handle_event ( &quot;save&quot; , _params , socket ) do uploaded_files = consume_uploaded_entries ( socket , entry , fn %{ path : tmp_path } -&gt; save_result = save_and_process_upload ( entry . client_name , tmp_path ) end ) # Make all check on uploaded_files {:ok, file} or {:ok, {:error, reason}} { :noreply , update ( socket , :uploaded_files , &amp; ( &amp;1 ++ uploaded_files ) ) } end defp save_and_process_upload ( name , tmp_path ) do thumb_result = FastThumbnail . create ( tmp_path , 200 , :webp ) case thumb_result do { :ok , thumb_path } -&gt; s3_result = upload_to_s3 ( thumb_path , name &lt;&gt; &quot;.webp&quot; ) case s3_result do { :ok , s3_url } -&gt; { :ok , s3_url } { :error , reason } -&gt; { :ok , { :error , reason } } # otherwise you can postone end { :error , reason } -&gt; { :error , reason } end end defp upload_to_s3 ( file_path , name_for_s3 ) do # Build your AWS client access_key = System . get_env ( &quot;AWS_ACCESS_KEY&quot; ) secret_key = System . get_env ( &quot;AWS_SECRET_KEY&quot; ) region = System . get_env ( &quot;AWS_REGION&quot; ) bucket = System . get_env ( &quot;AWS_BUCKET_NAME&quot; ) || &quot;my-bucket&quot; client = AWS.Client . create ( access_key , secret_key , region ) # Read the local WebP thumbnail bytes file_body = File . read! ( file_path ) # We&#39;ll store it in S3 at some key (like &quot;thumbnails/&lt;filename&gt;.webp&quot;) # This is just an example – adjust folder/paths as needed folder = &quot;thumbnails&quot; key = &quot; \#{ folder } / \#{ name_for_s3 } &quot; s3_url = &quot;https://s3. \#{ region } .amazonaws.com/ \#{ bucket } / \#{ key } &quot; # S3 `put_object` params put_params = %{ &quot;Body&quot; =&gt; file_body , &quot;ContentType&quot; =&gt; &quot;image/webp&quot; , &quot;Metadata&quot; =&gt; %{ &quot;OriginalName&quot; =&gt; name_for_s3 } } case AWS.S3 . put_object ( client , bucket , key , put_params ) do { :ok , _ , _ } -&gt; { :ok , s3_url } { :error , reason } -&gt; { :error , reason } end end end With this, you have a LiveView flow that: Accepts user uploads, Creates a resized webp thumbnail, Uploads it to S3, Returns the final S3 URL or a local URL. Under the hood, the Elixir function calls a Rust NIF which performs a single-pass crop+resize operation using fast_image_resize . The resized bytes are either: Written back to disk in the same or different format, or Returned to Elixir as a base64 string.","ref":"readme.html#example-liveview"},{"type":"extras","title":"FastThumbnail - Credits","doc":"fast_image_resize – the Rust crate that powers the SIMD-accelerated resizing. See also: Crates.io Docs.rs rustler – used for building the native Rust code as an Elixir NIF.","ref":"readme.html#credits"},{"type":"extras","title":"FastThumbnail - License","doc":"FastThumbnail is licensed under the Apache License, Version 2.0 . fast_image_resize is distributed under its own license. Please refer to its repository for details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Apache License Version 2.0, January 2004 http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION 1. Definitions. &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work. 2. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form. 3. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed. 4. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: (a) You must give any other recipients of the Work or Derivative Works a copy of this License; and (b) You must cause any modified files to carry prominent notices stating that You changed the files; and (c) You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License. You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License. 5. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions. 6. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file. 7. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License. 8. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages. 9. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS APPENDIX: How to apply the Apache License to your work. To apply the Apache License to your work, attach the following boilerplate notice, with the fields enclosed by brackets &quot;[]&quot; replaced with your own identifying information. (Don't include the brackets!) The text should be enclosed in the appropriate comment syntax for the file format. We also recommend that a file or class name and description of purpose be included on the same &quot;printed page&quot; as the copyright notice for easier identification within third-party archives. Copyright [yyyy] [name of copyright owner] Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html"}]